@@ -2,7 +2,7 @@ import json
 from pathlib import Path
 from threading import Lock
 
-from je_web_runner.utils.exception.exception_tag import cant_find_json_error, cant_save_json_error
+from je_web_runner.utils.exception.exception_tags import cant_find_json_error, cant_save_json_error
 from je_web_runner.utils.exception.exceptions import WebRunnerJsonException
 
 lock = Lock()
